==> QupZilla-2.2.4.tar.xz: QupZilla-2.2.4/src/plugins/StatusBarIcons/translations/ja_JP.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="ja_JP" version="2.1">
<context>
    <name>SBI_ImagesIcon</name>
    <message>
        <location filename="../sbi_imagesicon.cpp" line="33"/>
        <source>Modify images loading settings per-site and globally</source>
        <translation>画像の読み込みの全体の設定、またはサイトごとの設定を調整する。</translation>
    </message>
    <message>
        <location filename="../sbi_imagesicon.cpp" line="57"/>
        <source>Current Page Settings</source>
        <translation>現在のページの設定</translation>
    </message>
    <message>
        <location filename="../sbi_imagesicon.cpp" line="60"/>
        <source>Disable loading images (temporarily)</source>
        <translation>画像の読み込みを(一時的に)無効にする</translation>
    </message>
    <message>
        <location filename="../sbi_imagesicon.cpp" line="63"/>
        <source>Enable loading images (temporarily)</source>
        <translation>画像の読み込みを(一時的に)有効にする</translation>
    </message>
    <message>
        <location filename="../sbi_imagesicon.cpp" line="67"/>
        <source>Global Settings</source>
        <translation>全体の設定</translation>
    </message>
    <message>
        <location filename="../sbi_imagesicon.cpp" line="69"/>
        <source>Automatically load images</source>
        <translation>自動的に画像を読み込む</translation>
    </message>
</context>
<context>
    <name>SBI_JavaScriptIcon</name>
    <message>
        <location filename="../sbi_javascripticon.cpp" line="34"/>
        <source>Modify JavaScript settings per-site and globally</source>
        <translation>Javascript の全体の設定、またはサイトごとの設定を調整する。</translation>
    </message>
    <message>
        <location filename="../sbi_javascripticon.cpp" line="51"/>
        <source>Current Page Settings</source>
        <translation>現在のページの設定</translation>
    </message>
    <message>
        <location filename="../sbi_javascripticon.cpp" line="54"/>
        <source>Disable JavaScript (temporarily)</source>
        <translation>JavaScript を(一時的に)無効にする</translation>
    </message>
    <message>
        <location filename="../sbi_javascripticon.cpp" line="57"/>
        <source>Enable JavaScript (temporarily)</source>
        <translation>JavaScript を(一時的に)有効にする</translation>
    </message>
    <message>
        <location filename="../sbi_javascripticon.cpp" line="66"/>
        <source>Global Settings</source>
        <translation>全体の設定</translation>
    </message>
    <message>
        <location filename="../sbi_javascripticon.cpp" line="67"/>
        <source>Manage JavaScript settings</source>
        <translation>JavaScript の設定の管理</translation>
    </message>
</context>
<context>
    <name>SBI_NetworkIcon</name>
    <message>
        <location filename="../sbi_networkicon.cpp" line="65"/>
        <source>Proxy Configuration</source>
        <translation>プロキシ設定</translation>
    </message>
    <message>
        <location filename="../sbi_networkicon.cpp" line="67"/>
        <source>Select proxy</source>
        <translation>プロキシの選択</translation>
    </message>
    <message>
        <location filename="../sbi_networkicon.cpp" line="81"/>
        <source>Empty</source>
        <translation>空</translation>
    </message>
    <message>
        <location filename="../sbi_networkicon.cpp" line="85"/>
        <source>Manage proxies</source>
        <translation>プロキシの管理</translation>
    </message>
    <message>
        <location filename="../sbi_networkicon.cpp" line="98"/>
        <source>Shows network status and manages proxy&lt;br/&gt;&lt;br/&gt;&lt;b&gt;Network:&lt;/b&gt;&lt;br/&gt;%1&lt;br/&gt;&lt;br/&gt;&lt;b&gt;Proxy:&lt;/b&gt;&lt;br/&gt;%2</source>
        <translation>ネットワークステータスの表示とプロキシの管理&lt;br/&gt;&lt;br/&gt;&lt;b&gt;ネットワーク:&lt;/b&gt;&lt;br/&gt;%1&lt;br/&gt;&lt;br/&gt;&lt;b&gt;プロキシ:&lt;/b&gt;&lt;br/&gt;%2</translation>
    </message>
    <message>
        <location filename="../sbi_networkicon.cpp" line="101"/>
        <source>Connected</source>
        <translation>接続済</translation>
    </message>
    <message>
        <location filename="../sbi_networkicon.cpp" line="104"/>
        <source>Offline</source>
        <translation>オフライン</translation>
    </message>
    <message>
        <location filename="../sbi_networkicon.cpp" line="109"/>
        <source>System proxy</source>
        <translation>システムのプロキシ設定</translation>
    </message>
    <message>
        <location filename="../sbi_networkicon.cpp" line="113"/>
        <source>No proxy</source>
        <translation>プロキシを使用しない</translation>
    </message>
    <message>
        <location filename="../sbi_networkicon.cpp" line="117"/>
        <source>User defined</source>
        <translation>ユーザー指定</translation>
    </message>
</context>
<context>
    <name>SBI_NetworkIconDialog</name>
    <message>
        <location filename="../sbi_networkicondialog.ui" line="14"/>
        <source>Proxy Manager</source>
        <translation>プロキシマネージャ</translation>
    </message>
    <message>
        <location filename="../sbi_networkicondialog.ui" line="28"/>
        <source>Select proxy: </source>
        <translation>プロキシの選択:</translation>
    </message>
    <message>
        <location filename="../sbi_networkicondialog.ui" line="38"/>
        <location filename="../sbi_networkicondialog.cpp" line="57"/>
        <source>Add proxy</source>
        <translation>プロキシの追加</translation>
    </message>
    <message>
        <location filename="../sbi_networkicondialog.ui" line="45"/>
        <source>Remove proxy</source>
        <translation>プロキシの削除</translation>
    </message>
    <message>
        <location filename="../sbi_networkicondialog.ui" line="69"/>
        <source>No proxies. You can add proxy by clicking on &lt;b&gt;Add&lt;/b&gt; button.</source>
        <translation>プロキシがありません。&lt;b&gt;追加&lt;/b&gt;ボタンをクリックするとプロキシが追加できます。</translation>
    </message>
    <message>
        <location filename="../sbi_networkicondialog.ui" line="104"/>
        <source>All changes must be saved with &lt;b&gt;Save&lt;/b&gt; button.</source>
        <translation>すべての変更は&lt;b&gt;保存する&lt;/b&gt;ボタンをクリックしないと保存されません。</translation>
    </message>
    <message>
        <location filename="../sbi_networkicondialog.cpp" line="57"/>
        <source>Name of proxy:</source>
        <translation>プロキシ名:</translation>
    </message>
    <message>
        <location filename="../sbi_networkicondialog.cpp" line="70"/>
        <source>Remove current proxy</source>
        <translation>現在のプロキシを削除する</translation>
    </message>
    <message>
        <location filename="../sbi_networkicondialog.cpp" line="70"/>
        <source>Are you sure you want to remove current proxy?</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>SBI_ProxyWidget</name>
    <message>
        <location filename="../sbi_proxywidget.ui" line="14"/>
        <source>Form</source>
        <translation>フォーム</translation>
    </message>
    <message>
        <location filename="../sbi_proxywidget.ui" line="23"/>
        <source>HTTP</source>
        <translation>HTTP</translation>
    </message>
    <message>
        <location filename="../sbi_proxywidget.ui" line="28"/>
        <source>SOCKS5</source>
        <translation>SOCKS5</translation>
    </message>
    <message>
        <location filename="../sbi_proxywidget.ui" line="39"/>
        <source>Port:</source>
        <translation>ポート番号:</translation>
    </message>
    <message>
        <location filename="../sbi_proxywidget.ui" line="76"/>
        <source>Username:</source>
        <translation>ユーザー名:</translation>
    </message>
    <message>
        <location filename="../sbi_proxywidget.ui" line="86"/>
        <source>Password:</source>
        <translation>パスワード:</translation>
    </message>
    <message>
        <location filename="../sbi_proxywidget.ui" line="111"/>
        <source>S&amp;ystem proxy configuration</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../sbi_proxywidget.ui" line="118"/>
        <source>&amp;Manual configuration</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>SBI_SettingsDialog</name>
    <message>
        <location filename="../sbi_settingsdialog.ui" line="14"/>
        <source>StatusBar Icons</source>
        <translation>ステータスバーアイコン</translation>
    </message>
    <message>
        <location filename="../sbi_settingsdialog.ui" line="48"/>
        <source>&lt;h3&gt;StatusBar Icons&lt;/h3&gt;</source>
        <translation>&lt;h3&gt;ステータスバーアイコン&lt;/h3&gt;</translation>
    </message>
    <message>
        <location filename="../sbi_settingsdialog.ui" line="70"/>
        <source>These icons will be displayed in statusbar:</source>
        <translation>これらのアイコンはステータスバーに表示されます:</translation>
    </message>
    <message>
        <location filename="../sbi_settingsdialog.ui" line="97"/>
        <source>Images Icon</source>
        <translation>画像アイコン</translation>
    </message>
    <message>
        <location filename="../sbi_settingsdialog.ui" line="104"/>
        <source>JavaScript Icon</source>
        <translation>Javascript アイコン</translation>
    </message>
    <message>
        <location filename="../sbi_settingsdialog.ui" line="111"/>
        <source>Network Icon</source>
        <translation>ネットワークアイコン</translation>
    </message>
    <message>
        <location filename="../sbi_settingsdialog.ui" line="118"/>
        <source>Zoom widget</source>
        <translation>ズームウィジェット</translation>
    </message>
</context>
<context>
    <name>SBI_ZoomWidget</name>
    <message>
        <location filename="../sbi_zoomwidget.cpp" line="48"/>
        <source>Zoom: %1%</source>
        <translation>ズーム: %1%</translation>
    </message>
</context>
</TS>

==> QupZilla-2.2.6.tar.xz: QupZilla-2.2.6/src/plugins/StatusBarIcons/translations/ja_JP.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="ja_JP" version="2.1">
<context>
    <name>SBI_ImagesIcon</name>
    <message>
        <location filename="../sbi_imagesicon.cpp" line="34"/>
        <source>Modify images loading settings per-site and globally</source>
        <translation>画像の読み込みの全体の設定、またはサイトごとの設定を調整する。</translation>
    </message>
    <message>
        <location filename="../sbi_imagesicon.cpp" line="58"/>
        <source>Current Page Settings</source>
        <translation>現在のページの設定</translation>
    </message>
    <message>
        <location filename="../sbi_imagesicon.cpp" line="61"/>
        <source>Disable loading images (temporarily)</source>
        <translation>画像の読み込みを(一時的に)無効にする</translation>
    </message>
    <message>
        <location filename="../sbi_imagesicon.cpp" line="64"/>
        <source>Enable loading images (temporarily)</source>
        <translation>画像の読み込みを(一時的に)有効にする</translation>
    </message>
    <message>
        <location filename="../sbi_imagesicon.cpp" line="68"/>
        <source>Global Settings</source>
        <translation>全体の設定</translation>
    </message>
    <message>
        <location filename="../sbi_imagesicon.cpp" line="70"/>
        <source>Automatically load images</source>
        <translation>自動的に画像を読み込む</translation>
    </message>
</context>
<context>
    <name>SBI_JavaScriptIcon</name>
    <message>
        <location filename="../sbi_javascripticon.cpp" line="34"/>
        <source>Modify JavaScript settings per-site and globally</source>
        <translation>Javascript の全体の設定、またはサイトごとの設定を調整する。</translation>
    </message>
    <message>
        <location filename="../sbi_javascripticon.cpp" line="51"/>
        <source>Current Page Settings</source>
        <translation>現在のページの設定</translation>
    </message>
    <message>
        <location filename="../sbi_javascripticon.cpp" line="54"/>
        <source>Disable JavaScript (temporarily)</source>
        <translation>JavaScript を(一時的に)無効にする</translation>
    </message>
    <message>
        <location filename="../sbi_javascripticon.cpp" line="57"/>
        <source>Enable JavaScript (temporarily)</source>
        <translation>JavaScript を(一時的に)有効にする</translation>
    </message>
    <message>
        <location filename="../sbi_javascripticon.cpp" line="66"/>
        <source>Global Settings</source>
        <translation>全体の設定</translation>
    </message>
    <message>
        <location filename="../sbi_javascripticon.cpp" line="67"/>
        <source>Manage JavaScript settings</source>
        <translation>JavaScript の設定の管理</translation>
    </message>
</context>
<context>
    <name>SBI_NetworkIcon</name>
    <message>
        <location filename="../sbi_networkicon.cpp" line="65"/>
        <source>Proxy Configuration</source>
        <translation>プロキシ設定</translation>
    </message>
    <message>
        <location filename="../sbi_networkicon.cpp" line="67"/>
        <source>Select proxy</source>
        <translation>プロキシの選択</translation>
    </message>
    <message>
        <location filename="../sbi_networkicon.cpp" line="81"/>
        <source>Empty</source>
        <translation>空</translation>
    </message>
    <message>
        <location filename="../sbi_networkicon.cpp" line="85"/>
        <source>Manage proxies</source>
        <translation>プロキシの管理</translation>
    </message>
    <message>
        <location filename="../sbi_networkicon.cpp" line="98"/>
        <source>Shows network status and manages proxy&lt;br/&gt;&lt;br/&gt;&lt;b&gt;Network:&lt;/b&gt;&lt;br/&gt;%1&lt;br/&gt;&lt;br/&gt;&lt;b&gt;Proxy:&lt;/b&gt;&lt;br/&gt;%2</source>
        <translation>ネットワークステータスの表示とプロキシの管理&lt;br/&gt;&lt;br/&gt;&lt;b&gt;ネットワーク:&lt;/b&gt;&lt;br/&gt;%1&lt;br/&gt;&lt;br/&gt;&lt;b&gt;プロキシ:&lt;/b&gt;&lt;br/&gt;%2</translation>
    </message>
    <message>
        <location filename="../sbi_networkicon.cpp" line="101"/>
        <source>Connected</source>
        <translation>接続済</translation>
    </message>
    <message>
        <location filename="../sbi_networkicon.cpp" line="104"/>
        <source>Offline</source>
        <translation>オフライン</translation>
    </message>
    <message>
        <location filename="../sbi_networkicon.cpp" line="109"/>
        <source>System proxy</source>
        <translation>システムのプロキシ設定</translation>
    </message>
    <message>
        <location filename="../sbi_networkicon.cpp" line="113"/>
        <source>No proxy</source>
        <translation>プロキシを使用しない</translation>
    </message>
    <message>
        <location filename="../sbi_networkicon.cpp" line="117"/>
        <source>User defined</source>
        <translation>ユーザー指定</translation>
    </message>
</context>
<context>
    <name>SBI_NetworkIconDialog</name>
    <message>
        <location filename="../sbi_networkicondialog.ui" line="14"/>
        <source>Proxy Manager</source>
        <translation>プロキシマネージャ</translation>
    </message>
    <message>
        <location filename="../sbi_networkicondialog.ui" line="28"/>
        <source>Select proxy: </source>
        <translation>プロキシの選択:</translation>
    </message>
    <message>
        <location filename="../sbi_networkicondialog.ui" line="38"/>
        <location filename="../sbi_networkicondialog.cpp" line="57"/>
        <source>Add proxy</source>
        <translation>プロキシの追加</translation>
    </message>
    <message>
        <location filename="../sbi_networkicondialog.ui" line="45"/>
        <source>Remove proxy</source>
        <translation>プロキシの削除</translation>
    </message>
    <message>
        <location filename="../sbi_networkicondialog.ui" line="69"/>
        <source>No proxies. You can add proxy by clicking on &lt;b&gt;Add&lt;/b&gt; button.</source>
        <translation>プロキシがありません。&lt;b&gt;追加&lt;/b&gt;ボタンをクリックするとプロキシが追加できます。</translation>
    </message>
    <message>
        <location filename="../sbi_networkicondialog.ui" line="104"/>
        <source>All changes must be saved with &lt;b&gt;Save&lt;/b&gt; button.</source>
        <translation>すべての変更は&lt;b&gt;保存する&lt;/b&gt;ボタンをクリックしないと保存されません。</translation>
    </message>
    <message>
        <location filename="../sbi_networkicondialog.cpp" line="57"/>
        <source>Name of proxy:</source>
        <translation>プロキシ名:</translation>
    </message>
    <message>
        <location filename="../sbi_networkicondialog.cpp" line="70"/>
        <source>Remove current proxy</source>
        <translation>現在のプロキシを削除する</translation>
    </message>
    <message>
        <location filename="../sbi_networkicondialog.cpp" line="70"/>
        <source>Are you sure you want to remove current proxy?</source>
        <translation>本当に現在のプロキシを削除しますか?</translation>
    </message>
</context>
<context>
    <name>SBI_ProxyWidget</name>
    <message>
        <location filename="../sbi_proxywidget.ui" line="14"/>
        <source>Form</source>
        <translation>フォーム</translation>
    </message>
    <message>
        <location filename="../sbi_proxywidget.ui" line="23"/>
        <source>HTTP</source>
        <translation>HTTP</translation>
    </message>
    <message>
        <location filename="../sbi_proxywidget.ui" line="28"/>
        <source>SOCKS5</source>
        <translation>SOCKS5</translation>
    </message>
    <message>
        <location filename="../sbi_proxywidget.ui" line="39"/>
        <source>Port:</source>
        <translation>ポート番号:</translation>
    </message>
    <message>
        <location filename="../sbi_proxywidget.ui" line="76"/>
        <source>Username:</source>
        <translation>ユーザー名:</translation>
    </message>
    <message>
        <location filename="../sbi_proxywidget.ui" line="86"/>
        <source>Password:</source>
        <translation>パスワード:</translation>
    </message>
    <message>
        <location filename="../sbi_proxywidget.ui" line="111"/>
        <source>S&amp;ystem proxy configuration</source>
        <translation>システムプロキシの設定(&amp;Y)</translation>
    </message>
    <message>
        <location filename="../sbi_proxywidget.ui" line="118"/>
        <source>&amp;Manual configuration</source>
        <translation>手動設定(&amp;M)</translation>
    </message>
</context>
<context>
    <name>SBI_SettingsDialog</name>
    <message>
        <location filename="../sbi_settingsdialog.ui" line="14"/>
        <source>StatusBar Icons</source>
        <translation>ステータスバーアイコン</translation>
    </message>
    <message>
        <location filename="../sbi_settingsdialog.ui" line="48"/>
        <source>&lt;h3&gt;StatusBar Icons&lt;/h3&gt;</source>
        <translation>&lt;h3&gt;ステータスバーアイコン&lt;/h3&gt;</translation>
    </message>
    <message>
        <location filename="../sbi_settingsdialog.ui" line="70"/>
        <source>These icons will be displayed in statusbar:</source>
        <translation>これらのアイコンはステータスバーに表示されます:</translation>
    </message>
    <message>
        <location filename="../sbi_settingsdialog.ui" line="97"/>
        <source>Images Icon</source>
        <translation>画像アイコン</translation>
    </message>
    <message>
        <location filename="../sbi_settingsdialog.ui" line="104"/>
        <source>JavaScript Icon</source>
        <translation>Javascript アイコン</translation>
    </message>
    <message>
        <location filename="../sbi_settingsdialog.ui" line="111"/>
        <source>Network Icon</source>
        <translation>ネットワークアイコン</translation>
    </message>
    <message>
        <location filename="../sbi_settingsdialog.ui" line="118"/>
        <source>Zoom widget</source>
        <translation>ズームウィジェット</translation>
    </message>
</context>
<context>
    <name>SBI_ZoomWidget</name>
    <message>
        <location filename="../sbi_zoomwidget.cpp" line="48"/>
        <source>Zoom: %1%</source>
        <translation>ズーム: %1%</translation>
    </message>
</context>
</TS>
